@@ -1,4 +1,4 @@
-"""Prepare the tests."""
+"""Configuration for the pytest test suite."""
 # pylint: disable=missing-function-docstring
 import os
 from pathlib import Path
